# we require dhcp-devel for libdhcp_control.h
%define dhcpver 12:4.0.0-4

# libnl is used to communicate with the kernel via netlink
%define libnlver 1.1

Summary: DHCPv6 - DHCP server and client for IPv6
Name:    dhcpv6
Version: 1.0.22
Release: 1%{?dist}
License: LGPLv2+
Group:   System Environment/Daemons
URL:     http://fedorahosted.org/dhcpv6/
Source0: http://fedorahosted.org/releases/d/h/%{name}/%{name}-%{version}.tar.gz

BuildRoot: %{_tmppath}/%{name}-%{version}-%{release}-root-%(%{__id_u} -n)
BuildRequires: flex
BuildRequires: bison
BuildRequires: autoconf
BuildRequires: automake
BuildRequires: libtool
BuildRequires: pkgconfig
BuildRequires: dhcp-devel >= %{dhcpver}
BuildRequires: libnl-devel >= %{libnlver}
Requires(post): chkconfig
Requires(preun): chkconfig initscripts
Requires(postun): initscripts

%description
Implements the Dynamic Host Configuration Protocol (DHCP) for Internet
Protocol version 6 (IPv6) networks in accordance with RFC 3315: Dynamic Host
Configuration Protocol for IPv6 (DHCPv6).  Consists of dhcp6s(8), the server
DHCP daemon, and dhcp6r(8), the DHCPv6 relay agent.

Install this package if you want to support dynamic configuration of IPv6
addresses and parameters on your IPv6 network.

%package -n dhcpv6-client
Summary:   DHCPv6 client
Requires:  initscripts >= 7.73
Group:     System Environment/Base
Obsoletes: dhcpv6_client

%description -n dhcpv6-client
Provides the client for the DHCPv6 protocol (RFC 3315) to support dynamic
configuration of IPv6 addresses and parameters.

%package -n libdhcp6client
Summary: The DHCPv6 client in a library for invocation by other programs
Group:   Development/Libraries

%description -n libdhcp6client
Provides the client for the DHCPv6 protocol (RFC 3315) to support dynamic
configuration of IPv6 addresses and parameters, in a library for invocation
by other programs.

%package -n libdhcp6client-devel
Summary:  Header files for development with the DHCPv6 client library
Group:    Development/Libraries
Requires: pkgconfig
Requires: libdhcp6client = %{version}-%{release}

%description -n libdhcp6client-devel
Header files for development with the DHCPv6 client library.

%package -n libdhcp6client-static
Summary:  Static archive for libdhcp6client
Group:    Development/Libraries
Requires: libdhcp6client-devel = %{version}-%{release}

%description -n libdhcp6client-static
The libdhcp6client-static package contains the static archive for
libdhcp6client.

%prep
%setup -q

%build
%configure
%{__make} %{?_smp_mflags}

%install
%{__rm} -rf %{buildroot}
%{__make} install DESTDIR=%{buildroot}

%{__rm} -rf %{buildroot}%{_libdir}/libdhcp6client.la

%{__mkdir} -p %{buildroot}/sbin
%{__mv} %{buildroot}%{_sbindir}/dhcp6c %{buildroot}/sbin/dhcp6c

%{__mkdir} -p %{buildroot}%{_localstatedir}/lib/%{name}

%post
/sbin/chkconfig --add dhcp6s
/sbin/chkconfig --add dhcp6r || :

%preun
if [ $1 = 0 ]; then
    /sbin/service dhcp6s status > /dev/null 2>&1
    if [ $? = 3 ]; then
        /sbin/service dhcp6s stop > /dev/null 2>&1
    fi

    /sbin/service dhcp6r status > /dev/null 2>&1
    if [ $? = 3 ]; then
        /sbin/service dhcp6r stop > /dev/null 2>&1
    fi

    /sbin/chkconfig --del dhcp6s
    /sbin/chkconfig --del dhcp6r || :
fi

%postun
if [ $1 -ge 1 ]; then
    /sbin/service dhcp6s condrestart >/dev/null 2>&1
    /sbin/service dhcp6r condrestart >/dev/null 2>&1 || :
fi

%post -n libdhcp6client -p /sbin/ldconfig

%postun -n libdhcp6client -p /sbin/ldconfig

%clean
%{__rm} -rf %{buildroot}

%files
%defattr(-,root,root,-)
%doc AUTHORS ChangeLog COPYING.LIB LICENSE README TODO
%attr(754,root,root) %{_sbindir}/dhcp6s
%attr(754,root,root) %{_sbindir}/dhcp6r
%attr(755,root,root) %config %{_initrddir}/dhcp6s
%attr(755,root,root) %config %{_initrddir}/dhcp6r
%config(noreplace) %{_sysconfdir}/sysconfig/dhcp6s
%config(noreplace) %{_sysconfdir}/sysconfig/dhcp6r
%config(noreplace) %{_sysconfdir}/dhcp6s.conf
%{_mandir}/man8/dhcp6s.8.gz
%{_mandir}/man5/dhcp6s.conf.5.gz
%{_mandir}/man8/dhcp6r.8.gz
%attr(750,root,root) %dir %{_localstatedir}/lib/%{name}

%files -n dhcpv6-client
%defattr(-,root,root,-)
%attr(750,root,root) /sbin/dhcp6c
%doc AUTHORS ChangeLog COPYING.LIB LICENSE README TODO
%config(noreplace) %{_sysconfdir}/dhcp6c.conf
%{_mandir}/man8/dhcp6c.8.gz
%{_mandir}/man5/dhcp6c.conf.5.gz
%attr(750,root,root) %dir %{_localstatedir}/lib/%{name}

%files -n libdhcp6client
%defattr(0755,root,root,0755)
%{_libdir}/libdhcp6client-*.so.*

%files -n libdhcp6client-devel
%defattr(0644,root,root,0755)
%{_includedir}/*
%{_libdir}/pkgconfig/libdhcp6client.pc
%{_libdir}/libdhcp6client.so

%files -n libdhcp6client-static
%defattr(0644,root,root,0755)
%{_libdir}/libdhcp6client.a

%changelog
* Thu Sep 11 2008 David Cantrell <dcantrell@redhat.com> - 1.0.22-1
- Upgrade to dhcpv6-1.0.22, changes include:
      Windows 2008 interoperability fixes for ADVERTISE msgs
      Information Refresh Time option support
      IA address option bug fixes
      Check DAD by interface type in REPLY msgs
      Clear request addr list when msg is sent successfully
      Call init_lease_hashes() in dhcp6c

* Tue Jul 29 2008 David Cantrell <dcantrell@redhat.com> - 1.0.21-1
- Upgrade to dhcpv6-1.0.21, changes include:
      Remove old dadlist variable reference in dhcp6c

* Tue Jul 29 2008 David Cantrell <dcantrell@redhat.com> - 1.0.20-1
- Upgrade to dhcpv6-1.0.20, changes include:
      Allow all legal device names in dhcp6c
      Delay sending Confirm until DAD completes for link-local addr
      Copy preferred address correctly when receiving Advertise
      Point to addrlist member when creating DNS server option
      Add the status option length to the IA option length
      Other bug fixes

* Tue Jun 17 2008 David Cantrell <dcantrell@redhat.com> - 1.0.19-1
- Upgrade to dhcpv6-1.0.19, changes include:
      Write server PID file after configuration file is parsed
      Remove temporary file during resolv.conf updates
      Debug message cleanups
      Allow MAX_DEVICE number of devices
      Support multiple IA options
      Update internal status correctly for RENEW/REBIND msgs
      Man page and usage screen updates
      Handle signals correctly for daemon processes
      Make sure PID files are written for all daemons
      Add command line options to override PID file locations
      Perform case-insensitive DNS search domain comparisions
      Fix possible SIGSEGV in get_if_rainfo()
      When dhcp6c requests information only, don't configure iface
      Support s390 virtual interfaces on s390 platform
      Init script cleanups

* Wed May 28 2008 David Cantrell <dcantrell@redhat.com> - 1.0.18-1
- Make dadlist in src/dad_parse.c a global

* Fri May 23 2008 David Cantrell <dcantrell@redhat.com> - 1.0.17-1
- Upgrade to dhcpv6-1.0.16, major changes:
      Use libnl rather than homegrown netlink code
      Better error handling in dhcp6c
      Updates to the dhcp6c usage screen and man page
      Record the correct PID for dhcp6c

* Wed Apr 23 2008 David Cantrell <dcantrell@redhat.com> - 1.0.15-1
- Upgrade to dhcpv6-1.0.15, major changes:
      Check DUID and IAID for duplicate host entries
      Do not include Interface-ID option in RELAY-REPL messages
      Use the last 4 bytes of the MAC address to generate new IAIDs
      Handle multiple nameservers in option 23 in DHCPv6 reply
      Do not modify /etc/radvd.conf from dhcp6c(8)

* Wed Mar 05 2008 David Cantrell <dcantrell@redhat.com> - 1.0.14-1
- Upgrade to dhcpv6-1.0.14, which renames some function calls that were
  missed in the 1.0.13 release

* Sun Mar 02 2008 David Cantrell <dcantrell@redhat.com> - 1.0.13-1
- Upgrade to dhcpv6-1.0.13, major changes:
      Actually remove -fvisibility=hidden
      Avoid symbol collisons with dprintf()
      Try to use network-functions to update resolv.conf
      Verify length of RELAY_REPL buffer correctly
      Update 'now' when checking expiration for each timer
      Add domain list option check to specify dnslist
      Fix RFC3315 section 17.2.2 bug
      Do not override yy_init so we're more compatible with flex

* Sat Mar 01 2008 David Cantrell <dcantrell@redhat.com> - 1.0.12-1
- Upgrade to dhcpv6-1.0.12

* Thu Jan 31 2008 David Cantrell <dcantrell@redhat.com> - 1.0.11-1
- Upgrade to dhcpv6-1.0.11

* Mon Jan 21 2008 David Cantrell <dcantrell@redhat.com> - 1.0.10-1
- Upgrade to dhcpv6-1.0.10

* Thu Jan 17 2008 David Cantrell <dcantrell@redhat.com> - 1.0.9-1
- Upgrade to dhcpv6-1.0.9

* Thu Jan 17 2008 David Cantrell <dcantrell@redhat.com> - 1.0.8-1
- Upgrade to dhcpv6-1.0.8

* Wed Jan 16 2008 David Cantrell <dcantrell@redhat.com> - 1.0.7-1
- Upgrade to dhcpv6-1.0.7

* Wed Jan 16 2008 David Cantrell <dcantrell@redhat.com> - 1.0.6-1
- Upgrade to dhcpv6-1.0.6
- License is now LGPL v2.1 or any later version

* Wed Dec 19 2007 David Cantrell <dcantrell@redhat.com> - 1.0.4-1
- Upgraded to new upstream version, dhcpv6-1.0.4
- RPM scriptlet updates
- Update URL and Source lines to reflect new project location

* Mon Dec 03 2007 David Cantrell <dcantrell@redhat.com> - 1.0.3-1
- Upgraded to new upstream version, dhcpv6-1.0.3
- Corrected package scriptlets for dhcp6s and dhcp6r service installation

* Fri Nov 30 2007 David Cantrell <dcantrell@redhat.com> - 1.0.2-1
- Upgraded to new upstream version, dhcpv6-1.0.2

* Fri Nov 09 2007 David Cantrell <dcantrell@redhat.com> - 0.99.0-2
- Rebuild

* Thu Nov 08 2007 David Cantrell <dcantrell@redhat.com> - 0.99.0-1
- Upgraded to new upstream version, dhcpv6-0.99.0

* Wed Oct 24 2007 David Cantrell <dcantrell@redhat.com> - 0.10-52
- Remove DHCPv6.Cflags variable from libdhcp6client.pc
- Install dhcpv6 headers for libdhcp6client to /usr/include/dhcp6client
- Remove the libdhcp_control.h header file
- Extract full files from libdhcp6client patch and store as Sources
- Require dhcp-devel >= 12:3.1.0 for libdhcp_control.h

* Tue Sep 11 2007 David Cantrell <dcantrell@redhat.com> - 0.10-51
- Fix chkconfig lines in init scripts
- Obsolete dhcpv6_client (not nvr specific) in dhcpv6-client (#324901)

* Mon Sep 10 2007 David Cantrell <dcantrell@redhat.com> - 0.10-50
- Fix more segfaults when dhcp6s starts with empty control files (#253968)

* Mon Sep 10 2007 David Cantrell <dcantrell@redhat.com> - 0.10-49
- Make dhcp6r and dhcp6s init scripts conform to Fedora guidelines (#246909)
- Let dhcp6c ignore reply msgs that contain IA_NA with T1 > T2 (#254194)
- In dhcp6c, do not remove leases no on the updated list (#265761)
- Retransmit confirm message in expected duration in dhcp6c (#251192)
- Store correct value to elapsed time option in solicit msg (#249451)
- Reassign IPv6 global address after confirm/reply msg in dhcp6c (#249466)

* Mon Sep 10 2007 David Cantrell <dcantrell@redhat.com> - 0.10-48
- Recognize 802.1Q VLAN network device names (#245115)

* Tue Sep 04 2007 David Cantrell <dcantrell@redhat.com> - 0.10-47
- Do not parse an empty /var/lib/dhcpv6/server6.leases file (#253968)

* Tue Aug 21 2007 David Cantrell <dcantrell@redhat.com> - 0.10-46
- Rebuild

* Thu Aug 02 2007 David Cantrell <dcantrell@redhat.com> - 0.10-45
- Rename the dhcpv6_client package to dhcpv6-client
- Remove incorrect documentation references in package descriptions

* Thu Aug 02 2007 David Cantrell <dcantrell@redhat.com> - 0.10-44
- License for dhcpv6 is actually BSD, changed the field

* Mon Jun 11 2007 David Cantrell <dcantrell@redhat.com> - 0.10-43
- Merge review (#225692)

* Thu Apr 26 2007 David Cantrell <dcantrell@redhat.com> - 0.10-42
- Init script fixes (#237973)

* Mon Mar 26 2007 David Cantrell <dcantrell@redhat.com> - 0.10-41
- Pass correct sockaddr size for salen parameter to getnameinfo() (#233900)
- Spec file cleanups per Fedora Packaging Guidelines

* Fri Feb 16 2007 David Cantrell <dcantrell@redhat.com> - 0.10-40
- Remove strlcat(), we don't use it or need it
- Close socket correctly in gethwid() (#229005)

* Fri Feb 09 2007 David Cantrell <dcantrell@redhat.com> - 0.10-39
- Fix build failures on x86_64 and ia64
- Remove parallel make flags
- Disable -Werror for now since flex-generated source fails miserably with it
- Remove yy_current_buffer from lease_token.l
- Added missing -fPIC to CFLAGS

* Thu Feb 08 2007 David Cantrell <dcantrell@redhat.com> - 0.10-38
- Fix up libdhcp6client patch so it doesn't copy the source then patch it
- Revert LOG_INFO changes back to LOG_DEBUG
- Move non-libdhcp6client patches to the main bugfix patch
- Remove the extra noise sent to the logging function
- Correct warnings so it compiles with -Werror
- Remove local htonl.h header, just use the /usr/include definitions
- Include <netinet/in.h> and remove inclusion of <linux/ipv6.h> and "htonl.h"
- Move dhcp6r source to its own patch file
- Put man page patches in to a single patch file
- Remove periods from the end of package summary lines (package review)
- Use preferred BuildRoot (package review)
- Only export the symbols we want in libdhcp6client (#216187)
- Keep flex-generated files for the debuginfo package

* Tue Feb 06 2007 David Cantrell <dcantrell@redhat.com> - 0.10-37
- Add missing ';;' on line 72 of dhcp6r init script

* Tue Feb 06 2007 David Cantrell <dcantrell@redhat.com> - 0.10-36
- Make dhcp6s and dhcp6r init scripts LSB compliant

* Mon Nov 27 2006 David Cantrell <dcantrell@redhat.com> - 0.10-35
- server6_addr.conf is not required for dhcp6s
- Resolves: rhbz#217309
- Man page for dhcp6s.conf should reference server-preference
- Resolves: rhbz#217308

* Thu Nov 16 2006 David Cantrell <dcantrell@redhat.com> - 0.10-34
- Set permission of libdhcp6client.so.1 to 0755 (#215911)

* Tue Oct 31 2006 David Cantrell <dcantrell@redhat.com> - 0.10-33
- spec file cleanup (remove NODEBUGINFO, useless code, etc)
- Patch rollup since a lot of the later patches overwrote previous patches
- Put typedef for dhcp_state_e before it's used in libdhcp_control.h (#212612)
- Include <sys/queue.h> rather than the old BSD queue.h in the source

* Fri Sep 29 2006 David Cantrell <dcantrell@redhat.com> - 0.10-32
- Line continuation slashes for init script description (#204713)

* Fri Aug 18 2006 Jesse Keating <jkeating@redhat.com> - 0.10-31
- rebuilt with latest binutils to pick up 64K -z commonpagesize on ppc*
  (#203001)

* Tue Jul 18 2006 Jason Vas Dias <jvdias@redhat.com> - 0.10-30
- fix bug 196429: 
  Allow clients from dhcpv6-0.10<=16 to get addresses. 
  >16, the server sent the prefix length; this is now
  conditional on the client sending the DHC6OPT_REQUEST_PREFIX,
  and can be disabled by the 'use-ra-prefix' dhcp6c.conf or 
  dhcp6s.conf setting. With the upstream version, the only
  way to set the clients' address prefixes was by router
  advertisement.

* Wed Jul 12 2006 Jesse Keating <jkeating@redhat.com> - 0.10-29.1
- rebuild

* Wed Jun 28 2006 Peter Jones <pjones@redhat.com> - 0.10-29
- getnameinfo needs the size of the incoming data, not NS_MAXHOST

* Thu Jun 22 2006 David Cantrell <dcantrell@redhat.com> - 0.10-28
- If link is down, exit rather than loop indefinitely (#195250)

* Tue Jun 20 2006 Peter Jones <pjones@redhat.com> - 0.10-27
- don't patch using autoconf, do it in the spec file so it can be
  patched on top of

* Thu Jun 08 2006 Jason Vas Dias<jvdias@redhat.com> 0.10-26
- libdhcp6client fix to retry bind() to linklocal address
  on EADDRNOTAVAIL for up to 5 seconds to give kernel time
  to create linklocal address.

* Fri May 26 2006 Jason Vas Dias<jvdias@redhat.com> 0.10-24.1
- misc libdhcp6client fixes

* Fri May 19 2006 Jason Vas Dias<jvdias@redhat.com> 0.10-24
- build libdhcp6client with -soname

* Wed May 17 2006 Jason Vas Dias<jvdias@redhat.com> 0.10-22
- Thanks, Karsten. Now building with libdhcp6client enabled.

* Wed May 17 2006 Karsten Hopp <karsten@redhat.de> 0.10-21
- change buildrequires from openssl top openssl-devel so that
  the configure checks actually work

* Sun May 14 2006 Jason Vas Dias <jvdias@redhat.com> - 0.10-20
- Produce the libdhcp6client library for invoking dhcp6c from
  within other programs.

* Wed May 10 2006 Jason Vas Dias <jvdias@redhat.com> - 0.10-18
- Make server send client the IPv6 address prefix in address lease;
  make client use it 
- prevent netlink.c generating error log message for NLMSG_DONE
- fix netlink.c IFLA_PROTINFO handling now that kernel defines it
- fix memory leak in client6_addr create_iaid
- disable 'install -s' for binaries

* Fri Feb 10 2006 Jesse Keating <jkeating@redhat.com> - 0.10-16.1
- bump again for double-long bug on ppc(64)

* Tue Feb 07 2006 Jason Vas Dias <jvdias@redhat.com> - 0.10-16
- rebuild for new gcc, glibc, glibc-kernheaders

* Sun Dec 18 2005 Jason Vas Dias<jvdias@redhat.com> - 0.10-15.2
- rebuild for new gcc & flex

* Fri Dec 09 2005 Jesse Keating <jkeating@redhat.com>
- rebuilt

* Wed Nov  9 2005 Tomas Mraz <tmraz@redhat.com> - 0.10-15
- rebuilt with new openssl

* Mon Aug 15 2005 Jason Vas Dias <jvdias@redhat.com>
- fix bug 165882: allow client to configure an interface which
  does not have an IPv4 address ( use getifaddrs instead of
  ioctl(sockfd, SIOGIFCONF, ...)
- fix bug 165884 (possibly!): force use of glibc's getifaddrs,
  not internal getifaddrs implementation

* Fri Apr 01 2005 Florian La Roche <laroche@redhat.com>
- made perms for /var/lib/dhcpv6 the same

* Fri Mar 25 2005 Florian La Roche <laroche@redhat.com>
- add "exit 0" to postun script

* Thu Jan 13 2005 Jason Vas Dias <jvdias@redhat.com> - 0.10-11
- Fix misc. compiler warnings and ms-dos formatted man-pages

* Wed Jan 12 2005 Jason Vas Dias <jvdias@redhat.com> - 0.10-11
- Add 'prefix-delegation-interface' option to allow write
- of radvd interface configuration other than that for 
- the interface the lease was received on.

* Mon Jan 10 2005 Jason Vas Dias <jvdias@redhat.com> - 0.10-10
- Fix bug 144585: dhcp6c wasn't writing radvd.conf in prefix delegation mode

* Sun Jan 9  2005 Jason Vas Dias <jvdias@redhat.com> - 0.10-10
- Add Relay Agent support. Thanks to  Brian Bluesker<bbuesker@qualcomm.com>
- for the patch to add relay support to the server and for submitting the 
- patch originally contributed by Cristian Cadar of NEC Europe to 
- DHCPv6-developer  mailing list.

* Fri Jan 7  2005 Jason Vas Dias <jvdias@redhat.com> - 0.10-9
- fix bug 143728: SEGV core on resolv.conf + radvd.conf update -
- yywrap()'s must return 1

* Mon Oct 18 2004 Jason Vas Dias <jvdias@redhat.com> - 0.10-7
- fix bug 136146: clean up code - prevent compiler warnings

* Mon Sep 13 2004 Jason Vas Dias <jvdias@redhat.com> - 0.10-6
- fix bug 132468 for bug 125712: invoke change_resolv_conf

* Mon Sep 13 2004 Bill Nottingham <notting@redhat.com> - 0.10-5
- don't run by default
- add chkconfig prereqs, postun script, etc.

* Thu Sep  2 2004 Jason Vas Dias <jvdias@redhat.com> - 0.10-3/4
- fixed missing %%defattr for dhcpv6_client - bug 131638

* Mon Aug 30 2004 Jason Vas Dias <jvdias@redhat.com> - 0.10-2
- Split into two packages: dhcpv6-*, containing server only,
- and dhcpv6_client-*, containing client only.

* Thu Aug 26 2004 Jason Vas Dias <jvdias@redhat.com> - 0.10-1 
- Initial build.

